Class: Google::Cloud::GkeHub::V1::BinaryAuthorizationConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/gkehub/v1/fleet.rb

Overview

BinaryAuthorizationConfig defines the fleet level configuration of binary authorization feature.

Defined Under Namespace

Modules: EvaluationMode Classes: PolicyBinding

Instance Attribute Summary collapse

Instance Attribute Details

#evaluation_mode::Google::Cloud::GkeHub::V1::BinaryAuthorizationConfig::EvaluationMode

Returns Optional. Mode of operation for binauthz policy evaluation.

Returns:



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'proto_docs/google/cloud/gkehub/v1/fleet.rb', line 147

class BinaryAuthorizationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Binauthz policy that applies to this cluster.
  # @!attribute [rw] name
  #   @return [::String]
  #     The relative resource name of the binauthz platform policy to audit. GKE
  #     platform policies have the following format:
  #     `projects/{project_number}/platforms/gke/policies/{policy_id}`.
  class PolicyBinding
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Binary Authorization mode of operation.
  module EvaluationMode
    # Default value
    EVALUATION_MODE_UNSPECIFIED = 0

    # Disable BinaryAuthorization
    DISABLED = 1

    # Use Binary Authorization with the policies specified in policy_bindings.
    POLICY_BINDINGS = 2
  end
end

#policy_bindings::Array<::Google::Cloud::GkeHub::V1::BinaryAuthorizationConfig::PolicyBinding>

Returns Optional. Binauthz policies that apply to this cluster.

Returns:



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'proto_docs/google/cloud/gkehub/v1/fleet.rb', line 147

class BinaryAuthorizationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Binauthz policy that applies to this cluster.
  # @!attribute [rw] name
  #   @return [::String]
  #     The relative resource name of the binauthz platform policy to audit. GKE
  #     platform policies have the following format:
  #     `projects/{project_number}/platforms/gke/policies/{policy_id}`.
  class PolicyBinding
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Binary Authorization mode of operation.
  module EvaluationMode
    # Default value
    EVALUATION_MODE_UNSPECIFIED = 0

    # Disable BinaryAuthorization
    DISABLED = 1

    # Use Binary Authorization with the policies specified in policy_bindings.
    POLICY_BINDINGS = 2
  end
end