Class: Google::Cloud::GkeHub::V1::BinaryAuthorizationConfig::PolicyBinding
- Inherits:
-
Object
- Object
- Google::Cloud::GkeHub::V1::BinaryAuthorizationConfig::PolicyBinding
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/gkehub/v1/fleet.rb
Overview
Binauthz policy that applies to this cluster.
Instance Attribute Summary collapse
-
#name ⇒ ::String
The relative resource name of the binauthz platform policy to audit.
Instance Attribute Details
#name ⇒ ::String
Returns The relative resource name of the binauthz platform policy to audit. GKE
platform policies have the following format:
projects/{project_number}/platforms/gke/policies/{policy_id}.
157 158 159 160 |
# File 'proto_docs/google/cloud/gkehub/v1/fleet.rb', line 157 class PolicyBinding include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |