Class: Google::Cloud::GkeHub::V1::CreateFeatureRequest
- Inherits:
-
Object
- Object
- Google::Cloud::GkeHub::V1::CreateFeatureRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/gkehub/v1/service.rb
Overview
Request message for the GkeHub.CreateFeature method.
Instance Attribute Summary collapse
-
#feature_id ⇒ ::String
The ID of the feature to create.
-
#parent ⇒ ::String
Required.
-
#request_id ⇒ ::String
A request ID to identify requests.
-
#resource ⇒ ::Google::Cloud::GkeHub::V1::Feature
The Feature resource to create.
Instance Attribute Details
#feature_id ⇒ ::String
Returns The ID of the feature to create.
951 952 953 954 |
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 951 class CreateFeatureRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent (project and location) where the Feature will be
created. Specified in the format projects/*/locations/*.
951 952 953 954 |
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 951 class CreateFeatureRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns A request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes after the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
951 952 953 954 |
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 951 class CreateFeatureRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#resource ⇒ ::Google::Cloud::GkeHub::V1::Feature
Returns The Feature resource to create.
951 952 953 954 |
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 951 class CreateFeatureRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |