Class: Google::Cloud::GkeHub::V1::FeatureResourceState
- Inherits:
-
Object
- Object
- Google::Cloud::GkeHub::V1::FeatureResourceState
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/gkehub/v1/feature.rb
Overview
FeatureResourceState describes the state of a Feature resource in the
GkeHub API. See FeatureState for the "running state" of the Feature in the
Fleet and across Memberships.
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#state ⇒ ::Google::Cloud::GkeHub::V1::FeatureResourceState::State
The current state of the Feature resource in the Hub API.
Instance Attribute Details
#state ⇒ ::Google::Cloud::GkeHub::V1::FeatureResourceState::State
Returns The current state of the Feature resource in the Hub API.
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'proto_docs/google/cloud/gkehub/v1/feature.rb', line 172 class FeatureResourceState include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # State describes the lifecycle status of a Feature. module State # State is unknown or not set. STATE_UNSPECIFIED = 0 # The Feature is being enabled, and the Feature resource is being created. # Once complete, the corresponding Feature will be enabled in this Fleet. ENABLING = 1 # The Feature is enabled in this Fleet, and the Feature resource is fully # available. ACTIVE = 2 # The Feature is being disabled in this Fleet, and the Feature resource # is being deleted. DISABLING = 3 # The Feature resource is being updated. UPDATING = 4 # The Feature resource is being updated by the Hub Service. SERVICE_UPDATING = 5 end end |