Module: Google::Cloud::GkeHub::V1::FeatureResourceState::State
- Defined in:
- proto_docs/google/cloud/gkehub/v1/feature.rb
Overview
State describes the lifecycle status of a Feature.
Constant Summary collapse
- STATE_UNSPECIFIED =
State is unknown or not set.
0- ENABLING =
The Feature is being enabled, and the Feature resource is being created. Once complete, the corresponding Feature will be enabled in this Fleet.
1- ACTIVE =
The Feature is enabled in this Fleet, and the Feature resource is fully available.
2- DISABLING =
The Feature is being disabled in this Fleet, and the Feature resource is being deleted.
3- UPDATING =
The Feature resource is being updated.
4- SERVICE_UPDATING =
The Feature resource is being updated by the Hub Service.
5