Class: Google::Cloud::GkeHub::V1::FeatureState

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/gkehub/v1/feature.rb

Overview

FeatureState describes the high-level state of a Feature. It may be used to describe a Feature's state at the environ-level, or per-membershop, depending on the context.

Defined Under Namespace

Modules: Code

Instance Attribute Summary collapse

Instance Attribute Details

#code::Google::Cloud::GkeHub::V1::FeatureState::Code

Returns The high-level, machine-readable status of this Feature.

Returns:



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'proto_docs/google/cloud/gkehub/v1/feature.rb', line 213

class FeatureState
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Code represents a machine-readable, high-level status of the Feature.
  module Code
    # Unknown or not set.
    CODE_UNSPECIFIED = 0

    # The Feature is operating normally.
    OK = 1

    # The Feature has encountered an issue, and is operating in a degraded
    # state. The Feature may need intervention to return to normal operation.
    # See the description and any associated Feature-specific details for more
    # information.
    WARNING = 2

    # The Feature is not operating or is in a severely degraded state.
    # The Feature may need intervention to return to normal operation.
    # See the description and any associated Feature-specific details for more
    # information.
    ERROR = 3
  end
end

#description::String

Returns A human-readable description of the current status.

Returns:

  • (::String)

    A human-readable description of the current status.



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'proto_docs/google/cloud/gkehub/v1/feature.rb', line 213

class FeatureState
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Code represents a machine-readable, high-level status of the Feature.
  module Code
    # Unknown or not set.
    CODE_UNSPECIFIED = 0

    # The Feature is operating normally.
    OK = 1

    # The Feature has encountered an issue, and is operating in a degraded
    # state. The Feature may need intervention to return to normal operation.
    # See the description and any associated Feature-specific details for more
    # information.
    WARNING = 2

    # The Feature is not operating or is in a severely degraded state.
    # The Feature may need intervention to return to normal operation.
    # See the description and any associated Feature-specific details for more
    # information.
    ERROR = 3
  end
end

#update_time::Google::Protobuf::Timestamp

Returns The time this status and any related Feature-specific details were updated.

Returns:



213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'proto_docs/google/cloud/gkehub/v1/feature.rb', line 213

class FeatureState
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Code represents a machine-readable, high-level status of the Feature.
  module Code
    # Unknown or not set.
    CODE_UNSPECIFIED = 0

    # The Feature is operating normally.
    OK = 1

    # The Feature has encountered an issue, and is operating in a degraded
    # state. The Feature may need intervention to return to normal operation.
    # See the description and any associated Feature-specific details for more
    # information.
    WARNING = 2

    # The Feature is not operating or is in a severely degraded state.
    # The Feature may need intervention to return to normal operation.
    # See the description and any associated Feature-specific details for more
    # information.
    ERROR = 3
  end
end