Class: Google::Cloud::GkeHub::V1::Fleet

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/gkehub/v1/fleet.rb

Overview

Fleet contains the Fleet-wide metadata and configuration.

Defined Under Namespace

Classes: LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. When the Fleet was created.

Returns:



63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'proto_docs/google/cloud/gkehub/v1/fleet.rb', line 63

class Fleet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#default_cluster_config::Google::Cloud::GkeHub::V1::DefaultClusterConfig

Returns Optional. The default cluster configurations to apply across the fleet.

Returns:



63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'proto_docs/google/cloud/gkehub/v1/fleet.rb', line 63

class Fleet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#delete_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. When the Fleet was deleted.

Returns:



63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'proto_docs/google/cloud/gkehub/v1/fleet.rb', line 63

class Fleet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#display_name::String

Returns Optional. A user-assigned display name of the Fleet. When present, it must be between 4 to 30 characters. Allowed characters are: lowercase and uppercase letters, numbers, hyphen, single-quote, double-quote, space, and exclamation point.

Example: Production Fleet.

Returns:

  • (::String)

    Optional. A user-assigned display name of the Fleet. When present, it must be between 4 to 30 characters. Allowed characters are: lowercase and uppercase letters, numbers, hyphen, single-quote, double-quote, space, and exclamation point.

    Example: Production Fleet



63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'proto_docs/google/cloud/gkehub/v1/fleet.rb', line 63

class Fleet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#labels::Google::Protobuf::Map{::String => ::String}

Returns Optional. Labels for this Fleet.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Optional. Labels for this Fleet.



63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'proto_docs/google/cloud/gkehub/v1/fleet.rb', line 63

class Fleet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#name::String (readonly)

Returns Output only. The full, unique resource name of this fleet in the format of projects/{project}/locations/{location}/fleets/{fleet}.

Each Google Cloud project can have at most one fleet resource, named "default".

Returns:

  • (::String)

    Output only. The full, unique resource name of this fleet in the format of projects/{project}/locations/{location}/fleets/{fleet}.

    Each Google Cloud project can have at most one fleet resource, named "default".



63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'proto_docs/google/cloud/gkehub/v1/fleet.rb', line 63

class Fleet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#state::Google::Cloud::GkeHub::V1::FleetLifecycleState (readonly)

Returns Output only. State of the namespace resource.

Returns:



63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'proto_docs/google/cloud/gkehub/v1/fleet.rb', line 63

class Fleet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#uid::String (readonly)

Returns Output only. Google-generated UUID for this resource. This is unique across all Fleet resources. If a Fleet resource is deleted and another resource with the same name is created, it gets a different uid.

Returns:

  • (::String)

    Output only. Google-generated UUID for this resource. This is unique across all Fleet resources. If a Fleet resource is deleted and another resource with the same name is created, it gets a different uid.



63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'proto_docs/google/cloud/gkehub/v1/fleet.rb', line 63

class Fleet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. When the Fleet was last updated.

Returns:



63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'proto_docs/google/cloud/gkehub/v1/fleet.rb', line 63

class Fleet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end