Class: Google::Cloud::GkeHub::V1::GenerateMembershipRBACRoleBindingYAMLRequest
- Inherits:
-
Object
- Object
- Google::Cloud::GkeHub::V1::GenerateMembershipRBACRoleBindingYAMLRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/gkehub/v1/service.rb
Overview
Request to generate a YAML of the RBAC policies for the specified RoleBinding and its associated impersonation resources.
Instance Attribute Summary collapse
-
#parent ⇒ ::String
Required.
-
#rbacrolebinding ⇒ ::Google::Cloud::GkeHub::V1::RBACRoleBinding
Required.
-
#rbacrolebinding_id ⇒ ::String
Required.
Instance Attribute Details
#parent ⇒ ::String
Returns Required. The parent (project and location) where the RBACRoleBinding will
be created. Specified in the format projects/*/locations/*/memberships/*.
576 577 578 579 |
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 576 class GenerateMembershipRBACRoleBindingYAMLRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#rbacrolebinding ⇒ ::Google::Cloud::GkeHub::V1::RBACRoleBinding
Returns Required. The rbacrolebindings to generate the YAML for.
576 577 578 579 |
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 576 class GenerateMembershipRBACRoleBindingYAMLRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#rbacrolebinding_id ⇒ ::String
Returns Required. Client chosen ID for the RBACRoleBinding. rbacrolebinding_id
must be a valid RFC 1123 compliant DNS label:
- At most 63 characters in length
- It must consist of lower case alphanumeric characters or
- - It must start and end with an alphanumeric character
Which can be expressed as the regex: [a-z0-9]([-a-z0-9]*[a-z0-9])?,
with a maximum length of 63 characters.
576 577 578 579 |
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 576 class GenerateMembershipRBACRoleBindingYAMLRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |