Class: Google::Cloud::GkeHub::V1::GetFeatureRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/gkehub/v1/service.rb

Overview

Request message for GkeHub.GetFeature method.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. The Feature resource name in the format projects/*/locations/*/features/*.

Returns:

  • (::String)

    Required. The Feature resource name in the format projects/*/locations/*/features/*



920
921
922
923
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 920

class GetFeatureRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#return_partial_success::Boolean

Returns Optional. If set to true, the response will return partial results when some regions are unreachable and the unreachable field in Feature proto will be populated. If set to false, the request will fail when some regions are unreachable.

Returns:

  • (::Boolean)

    Optional. If set to true, the response will return partial results when some regions are unreachable and the unreachable field in Feature proto will be populated. If set to false, the request will fail when some regions are unreachable.



920
921
922
923
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 920

class GetFeatureRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end