Class: Google::Cloud::GkeHub::V1::ListBoundMembershipsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/gkehub/v1/service.rb

Overview

Request to list Memberships bound to a Scope.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Optional. Lists Memberships that match the filter expression, following the syntax outlined in https://google.aip.dev/160. Currently, filtering can be done only based on Memberships's name, labels, create_time, update_time, and unique_id.

Returns:

  • (::String)

    Optional. Lists Memberships that match the filter expression, following the syntax outlined in https://google.aip.dev/160. Currently, filtering can be done only based on Memberships's name, labels, create_time, update_time, and unique_id.



639
640
641
642
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 639

class ListBoundMembershipsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. When requesting a 'page' of resources, page_size specifies number of resources to return. If unspecified or set to 0, all resources will be returned. Pagination is currently not supported; therefore, setting this field does not have any impact for now.

Returns:

  • (::Integer)

    Optional. When requesting a 'page' of resources, page_size specifies number of resources to return. If unspecified or set to 0, all resources will be returned. Pagination is currently not supported; therefore, setting this field does not have any impact for now.



639
640
641
642
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 639

class ListBoundMembershipsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. Token returned by previous call to ListBoundMemberships which specifies the position in the list from where to continue listing the resources.

Returns:

  • (::String)

    Optional. Token returned by previous call to ListBoundMemberships which specifies the position in the list from where to continue listing the resources.



639
640
641
642
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 639

class ListBoundMembershipsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#scope_name::String

Returns Required. Name of the Scope, in the format projects/*/locations/global/scopes/*, to which the Memberships are bound.

Returns:

  • (::String)

    Required. Name of the Scope, in the format projects/*/locations/global/scopes/*, to which the Memberships are bound.



639
640
641
642
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 639

class ListBoundMembershipsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end