Class: Google::Cloud::GkeHub::V1::ListFeaturesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/gkehub/v1/service.rb

Overview

Request message for GkeHub.ListFeatures method.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Lists Features that match the filter expression, following the syntax outlined in https://google.aip.dev/160.

Examples:

  • Feature with the name "servicemesh" in project "foo-proj":

    name = "projects/foo-proj/locations/global/features/servicemesh"

  • Features that have a label called foo:

    labels.foo:*

  • Features that have a label called foo whose value is bar:

    labels.foo = bar.

Returns:

  • (::String)

    Lists Features that match the filter expression, following the syntax outlined in https://google.aip.dev/160.

    Examples:

    • Feature with the name "servicemesh" in project "foo-proj":

      name = "projects/foo-proj/locations/global/features/servicemesh"

    • Features that have a label called foo:

      labels.foo:*

    • Features that have a label called foo whose value is bar:

      labels.foo = bar



890
891
892
893
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 890

class ListFeaturesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#order_by::String

Returns One or more fields to compare and use to sort the output. See https://google.aip.dev/132#ordering.

Returns:



890
891
892
893
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 890

class ListFeaturesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns When requesting a 'page' of resources, page_size specifies number of resources to return. If unspecified or set to 0, all resources will be returned.

Returns:

  • (::Integer)

    When requesting a 'page' of resources, page_size specifies number of resources to return. If unspecified or set to 0, all resources will be returned.



890
891
892
893
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 890

class ListFeaturesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Token returned by previous call to ListFeatures which specifies the position in the list from where to continue listing the resources.

Returns:

  • (::String)

    Token returned by previous call to ListFeatures which specifies the position in the list from where to continue listing the resources.



890
891
892
893
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 890

class ListFeaturesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent (project and location) where the Features will be listed. Specified in the format projects/*/locations/*.

Returns:

  • (::String)

    Required. The parent (project and location) where the Features will be listed. Specified in the format projects/*/locations/*.



890
891
892
893
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 890

class ListFeaturesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#return_partial_success::Boolean

Returns Optional. If set to true, the response will return partial results when some regions are unreachable and the unreachable field in Feature proto will be populated. If set to false, the request will fail when some regions are unreachable.

Returns:

  • (::Boolean)

    Optional. If set to true, the response will return partial results when some regions are unreachable and the unreachable field in Feature proto will be populated. If set to false, the request will fail when some regions are unreachable.



890
891
892
893
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 890

class ListFeaturesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end