Class: Google::Cloud::GkeHub::V1::ListFeaturesResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/gkehub/v1/service.rb

Overview

Response message for the GkeHub.ListFeatures method.

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token::String

Returns A token to request the next page of resources from the ListFeatures method. The value of an empty string means that there are no more resources to return.

Returns:

  • (::String)

    A token to request the next page of resources from the ListFeatures method. The value of an empty string means that there are no more resources to return.



904
905
906
907
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 904

class ListFeaturesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#resources::Array<::Google::Cloud::GkeHub::V1::Feature>

Returns The list of matching Features.

Returns:



904
905
906
907
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 904

class ListFeaturesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end