Class: Google::Cloud::GkeHub::V1::ListFleetsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/gkehub/v1/service.rb

Overview

Request message for the GkeHub.ListFleets method.

Instance Attribute Summary collapse

Instance Attribute Details

#page_size::Integer

Returns Optional. The maximum number of fleets to return. The service may return fewer than this value. If unspecified, at most 200 fleets will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

Returns:

  • (::Integer)

    Optional. The maximum number of fleets to return. The service may return fewer than this value. If unspecified, at most 200 fleets will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.



1089
1090
1091
1092
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 1089

class ListFleetsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A page token, received from a previous ListFleets call. Provide this to retrieve the subsequent page.

When paginating, all other parameters provided to ListFleets must match the call that provided the page token.

Returns:

  • (::String)

    Optional. A page token, received from a previous ListFleets call. Provide this to retrieve the subsequent page.

    When paginating, all other parameters provided to ListFleets must match the call that provided the page token.



1089
1090
1091
1092
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 1089

class ListFleetsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The organization or project to list for Fleets under, in the format organizations/*/locations/* or projects/*/locations/*.

Returns:

  • (::String)

    Required. The organization or project to list for Fleets under, in the format organizations/*/locations/* or projects/*/locations/*.



1089
1090
1091
1092
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 1089

class ListFleetsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end