Class: Google::Cloud::GkeHub::V1::ListFleetsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/gkehub/v1/service.rb

Overview

Response message for the GkeHub.ListFleetsResponse method.

Instance Attribute Summary collapse

Instance Attribute Details

#fleets::Array<::Google::Cloud::GkeHub::V1::Fleet>

Returns The list of matching fleets.

Returns:



1103
1104
1105
1106
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 1103

class ListFleetsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. The token is only valid for 1h.

Returns:

  • (::String)

    A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. The token is only valid for 1h.



1103
1104
1105
1106
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 1103

class ListFleetsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end