Class: Google::Cloud::GkeHub::V1::ListMembershipBindingsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/gkehub/v1/service.rb

Overview

List of MembershipBindings.

Instance Attribute Summary collapse

Instance Attribute Details

#membership_bindings::Array<::Google::Cloud::GkeHub::V1::MembershipBinding>

Returns The list of membership_bindings.

Returns:



410
411
412
413
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 410

class ListMembershipBindingsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token to request the next page of resources from the ListMembershipBindings method. The value of an empty string means that there are no more resources to return.

Returns:

  • (::String)

    A token to request the next page of resources from the ListMembershipBindings method. The value of an empty string means that there are no more resources to return.



410
411
412
413
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 410

class ListMembershipBindingsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#unreachable::Array<::String>

Returns List of locations that could not be reached while fetching this list.

Returns:

  • (::Array<::String>)

    List of locations that could not be reached while fetching this list.



410
411
412
413
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 410

class ListMembershipBindingsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end