Class: Google::Cloud::GkeHub::V1::ListMembershipRBACRoleBindingsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/gkehub/v1/service.rb

Overview

Request to list Membership RBACRoleBindings.

Instance Attribute Summary collapse

Instance Attribute Details

#page_size::Integer

Returns Optional. When requesting a 'page' of resources, page_size specifies number of resources to return. If unspecified or set to 0, all resources will be returned.

Returns:

  • (::Integer)

    Optional. When requesting a 'page' of resources, page_size specifies number of resources to return. If unspecified or set to 0, all resources will be returned.



534
535
536
537
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 534

class ListMembershipRBACRoleBindingsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. Token returned by previous call to ListMembershipRBACRoleBindings which specifies the position in the list from where to continue listing the resources.

Returns:

  • (::String)

    Optional. Token returned by previous call to ListMembershipRBACRoleBindings which specifies the position in the list from where to continue listing the resources.



534
535
536
537
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 534

class ListMembershipRBACRoleBindingsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent (project and location) where the Features will be listed. Specified in the format projects/*/locations/*/memberships/*.

Returns:

  • (::String)

    Required. The parent (project and location) where the Features will be listed. Specified in the format projects/*/locations/*/memberships/*.



534
535
536
537
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 534

class ListMembershipRBACRoleBindingsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end