Class: Google::Cloud::GkeHub::V1::ListMembershipRBACRoleBindingsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/gkehub/v1/service.rb

Overview

List of Membership RBACRoleBindings.

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token::String

Returns A token to request the next page of resources from the ListMembershipRBACRoleBindings method. The value of an empty string means that there are no more resources to return.

Returns:

  • (::String)

    A token to request the next page of resources from the ListMembershipRBACRoleBindings method. The value of an empty string means that there are no more resources to return.



551
552
553
554
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 551

class ListMembershipRBACRoleBindingsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#rbacrolebindings::Array<::Google::Cloud::GkeHub::V1::RBACRoleBinding>

Returns The list of Membership RBACRoleBindings.

Returns:



551
552
553
554
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 551

class ListMembershipRBACRoleBindingsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#unreachable::Array<::String>

Returns List of locations that could not be reached while fetching this list.

Returns:

  • (::Array<::String>)

    List of locations that could not be reached while fetching this list.



551
552
553
554
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 551

class ListMembershipRBACRoleBindingsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end