Class: Google::Cloud::GkeHub::V1::ListMembershipsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::GkeHub::V1::ListMembershipsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/gkehub/v1/service.rb
Overview
Response message for the GkeHub.ListMemberships method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
A token to request the next page of resources from the
ListMembershipsmethod. -
#resources ⇒ ::Array<::Google::Cloud::GkeHub::V1::Membership>
The list of matching Memberships.
-
#unreachable ⇒ ::Array<::String>
List of locations that could not be reached while fetching this list.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns A token to request the next page of resources from the
ListMemberships method. The value of an empty string means that
there are no more resources to return.
602 603 604 605 |
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 602 class ListMembershipsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#resources ⇒ ::Array<::Google::Cloud::GkeHub::V1::Membership>
Returns The list of matching Memberships.
602 603 604 605 |
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 602 class ListMembershipsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unreachable ⇒ ::Array<::String>
Returns List of locations that could not be reached while fetching this list.
602 603 604 605 |
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 602 class ListMembershipsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |