Class: Google::Cloud::GkeHub::V1::ListPermittedScopesResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/gkehub/v1/service.rb

Overview

List of permitted Scopes.

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token::String

Returns A token to request the next page of resources from the ListPermittedScopes method. The value of an empty string means that there are no more resources to return.

Returns:

  • (::String)

    A token to request the next page of resources from the ListPermittedScopes method. The value of an empty string means that there are no more resources to return.



320
321
322
323
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 320

class ListPermittedScopesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#scopes::Array<::Google::Cloud::GkeHub::V1::Scope>

Returns The list of permitted Scopes.

Returns:



320
321
322
323
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 320

class ListPermittedScopesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end