Class: Google::Cloud::GkeHub::V1::ListScopeNamespacesResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/gkehub/v1/service.rb

Overview

List of fleet namespaces.

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token::String

Returns A token to request the next page of resources from the ListNamespaces method. The value of an empty string means that there are no more resources to return.

Returns:

  • (::String)

    A token to request the next page of resources from the ListNamespaces method. The value of an empty string means that there are no more resources to return.



111
112
113
114
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 111

class ListScopeNamespacesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#scope_namespaces::Array<::Google::Cloud::GkeHub::V1::Namespace>

Returns The list of fleet namespaces.

Returns:



111
112
113
114
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 111

class ListScopeNamespacesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end