Class: Google::Cloud::GkeHub::V1::ListScopeRBACRoleBindingsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/gkehub/v1/service.rb

Overview

List of Scope RBACRoleBindings.

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token::String

Returns A token to request the next page of resources from the ListScopeRBACRoleBindings method. The value of an empty string means that there are no more resources to return.

Returns:

  • (::String)

    A token to request the next page of resources from the ListScopeRBACRoleBindings method. The value of an empty string means that there are no more resources to return.



202
203
204
205
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 202

class ListScopeRBACRoleBindingsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#rbacrolebindings::Array<::Google::Cloud::GkeHub::V1::RBACRoleBinding>

Returns The list of Scope RBACRoleBindings.

Returns:



202
203
204
205
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 202

class ListScopeRBACRoleBindingsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end