Class: Google::Cloud::GkeHub::V1::ListScopesResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/gkehub/v1/service.rb

Overview

List of Scopes.

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token::String

Returns A token to request the next page of resources from the ListScopes method. The value of an empty string means that there are no more resources to return.

Returns:

  • (::String)

    A token to request the next page of resources from the ListScopes method. The value of an empty string means that there are no more resources to return.



286
287
288
289
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 286

class ListScopesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#scopes::Array<::Google::Cloud::GkeHub::V1::Scope>

Returns The list of Scopes.

Returns:



286
287
288
289
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 286

class ListScopesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end