Class: Google::Cloud::GkeHub::V1::RBACRoleBinding::Role
- Inherits:
-
Object
- Object
- Google::Cloud::GkeHub::V1::RBACRoleBinding::Role
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/gkehub/v1/fleet.rb
Overview
Role is the type for Kubernetes roles
Defined Under Namespace
Modules: PredefinedRoles
Instance Attribute Summary collapse
-
#custom_role ⇒ ::String
Optional.
-
#predefined_role ⇒ ::Google::Cloud::GkeHub::V1::RBACRoleBinding::Role::PredefinedRoles
Predefined_role is the Kubernetes default role to use.
Instance Attribute Details
#custom_role ⇒ ::String
Returns Optional. custom_role is the name of a custom KubernetesClusterRole to use.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 |
# File 'proto_docs/google/cloud/gkehub/v1/fleet.rb', line 372 class Role include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # PredefinedRoles is an ENUM representation of the default Kubernetes Roles module PredefinedRoles # UNKNOWN UNKNOWN = 0 # ADMIN has EDIT and RBAC permissions ADMIN = 1 # EDIT can edit all resources except RBAC EDIT = 2 # VIEW can only read resources VIEW = 3 # ANTHOS_SUPPORT gives Google Support read-only access to a number of # cluster resources. ANTHOS_SUPPORT = 4 end end |
#predefined_role ⇒ ::Google::Cloud::GkeHub::V1::RBACRoleBinding::Role::PredefinedRoles
Returns predefined_role is the Kubernetes default role to use.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 |
# File 'proto_docs/google/cloud/gkehub/v1/fleet.rb', line 372 class Role include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # PredefinedRoles is an ENUM representation of the default Kubernetes Roles module PredefinedRoles # UNKNOWN UNKNOWN = 0 # ADMIN has EDIT and RBAC permissions ADMIN = 1 # EDIT can edit all resources except RBAC EDIT = 2 # VIEW can only read resources VIEW = 3 # ANTHOS_SUPPORT gives Google Support read-only access to a number of # cluster resources. ANTHOS_SUPPORT = 4 end end |