Class: Google::Cloud::GkeHub::V1::SecurityPostureConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/gkehub/v1/fleet.rb

Overview

SecurityPostureConfig defines the flags needed to enable/disable features for the Security Posture API.

Defined Under Namespace

Modules: Mode, VulnerabilityMode

Instance Attribute Summary collapse

Instance Attribute Details

#mode::Google::Cloud::GkeHub::V1::SecurityPostureConfig::Mode

Returns Sets which mode to use for Security Posture features.

Returns:



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'proto_docs/google/cloud/gkehub/v1/fleet.rb', line 103

class SecurityPostureConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Mode defines enablement mode for GKE Security posture features.
  module Mode
    # Default value not specified.
    MODE_UNSPECIFIED = 0

    # Disables Security Posture features on the cluster.
    DISABLED = 1

    # Applies Security Posture features on the cluster.
    BASIC = 2

    # Applies the Security Posture off cluster Enterprise level features.
    ENTERPRISE = 3
  end

  # VulnerabilityMode defines enablement mode for vulnerability scanning.
  module VulnerabilityMode
    # Default value not specified.
    VULNERABILITY_MODE_UNSPECIFIED = 0

    # Disables vulnerability scanning on the cluster.
    VULNERABILITY_DISABLED = 1

    # Applies basic vulnerability scanning on the cluster.
    VULNERABILITY_BASIC = 2

    # Applies the Security Posture's vulnerability on cluster Enterprise level
    # features.
    VULNERABILITY_ENTERPRISE = 3
  end
end

#vulnerability_mode::Google::Cloud::GkeHub::V1::SecurityPostureConfig::VulnerabilityMode

Returns Sets which mode to use for vulnerability scanning.

Returns:



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'proto_docs/google/cloud/gkehub/v1/fleet.rb', line 103

class SecurityPostureConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Mode defines enablement mode for GKE Security posture features.
  module Mode
    # Default value not specified.
    MODE_UNSPECIFIED = 0

    # Disables Security Posture features on the cluster.
    DISABLED = 1

    # Applies Security Posture features on the cluster.
    BASIC = 2

    # Applies the Security Posture off cluster Enterprise level features.
    ENTERPRISE = 3
  end

  # VulnerabilityMode defines enablement mode for vulnerability scanning.
  module VulnerabilityMode
    # Default value not specified.
    VULNERABILITY_MODE_UNSPECIFIED = 0

    # Disables vulnerability scanning on the cluster.
    VULNERABILITY_DISABLED = 1

    # Applies basic vulnerability scanning on the cluster.
    VULNERABILITY_BASIC = 2

    # Applies the Security Posture's vulnerability on cluster Enterprise level
    # features.
    VULNERABILITY_ENTERPRISE = 3
  end
end