Class: Google::Cloud::GkeHub::V1::UpdateScopeNamespaceRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/gkehub/v1/service.rb

Overview

Request to update a fleet namespace.

Instance Attribute Summary collapse

Instance Attribute Details

#scope_namespace::Google::Cloud::GkeHub::V1::Namespace

Returns Required. A namespace with fields updated. The 'name' field in this namespace is used to identify the resource to update. Given 'updated' prefix to follow go/proto-best-practices-checkers#keyword_conflict.

Returns:

  • (::Google::Cloud::GkeHub::V1::Namespace)

    Required. A namespace with fields updated. The 'name' field in this namespace is used to identify the resource to update. Given 'updated' prefix to follow go/proto-best-practices-checkers#keyword_conflict



67
68
69
70
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 67

class UpdateScopeNamespaceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#update_mask::Google::Protobuf::FieldMask

Returns Required. The fields to be updated.

Returns:



67
68
69
70
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 67

class UpdateScopeNamespaceRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end