Class: Google::Cloud::GkeHub::RbacRoleBindingActuation::V1::FeatureSpec
- Inherits:
-
Object
- Object
- Google::Cloud::GkeHub::RbacRoleBindingActuation::V1::FeatureSpec
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/gkehub/v1/rbacrolebindingactuation/rbacrolebindingactuation.rb
Overview
RBAC RoleBinding Actuation: The Hub-wide input for the RBACRoleBindingActuation feature.
Instance Attribute Summary collapse
-
#allowed_custom_roles ⇒ ::Array<::String>
The list of allowed custom roles (ClusterRoles).
Instance Attribute Details
#allowed_custom_roles ⇒ ::Array<::String>
Returns The list of allowed custom roles (ClusterRoles). If a ClusterRole is not part of this list, it cannot be used in a Scope RBACRoleBinding. If a ClusterRole in this list is in use, it cannot be removed from the list.
32 33 34 35 |
# File 'proto_docs/google/cloud/gkehub/v1/rbacrolebindingactuation/rbacrolebindingactuation.rb', line 32 class FeatureSpec include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |