Class: Google::Cloud::GkeHub::V1::CreateScopeNamespaceRequest
- Inherits:
-
Object
- Object
- Google::Cloud::GkeHub::V1::CreateScopeNamespaceRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/gkehub/v1/service.rb
Overview
Request to create a fleet namespace.
Instance Attribute Summary collapse
-
#parent ⇒ ::String
Required.
-
#scope_namespace ⇒ ::Google::Cloud::GkeHub::V1::Namespace
Required.
-
#scope_namespace_id ⇒ ::String
Required.
Instance Attribute Details
#parent ⇒ ::String
Returns Required. The parent (project and location) where the Namespace will be
created. Specified in the format projects/*/locations/*/scopes/*.
53 54 55 56 |
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 53 class CreateScopeNamespaceRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#scope_namespace ⇒ ::Google::Cloud::GkeHub::V1::Namespace
Returns Required. The fleet namespace to create.
53 54 55 56 |
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 53 class CreateScopeNamespaceRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#scope_namespace_id ⇒ ::String
Returns Required. Client chosen ID for the Namespace. namespace_id must be a
valid RFC 1123 compliant DNS label:
- At most 63 characters in length
- It must consist of lower case alphanumeric characters or
- - It must start and end with an alphanumeric character
Which can be expressed as the regex: [a-z0-9]([-a-z0-9]*[a-z0-9])?,
with a maximum length of 63 characters.
53 54 55 56 |
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 53 class CreateScopeNamespaceRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |