Class: Google::Cloud::GkeHub::V1::DefaultClusterConfig
- Inherits:
-
Object
- Object
- Google::Cloud::GkeHub::V1::DefaultClusterConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/gkehub/v1/fleet.rb
Overview
DefaultClusterConfig describes the default cluster configurations to be applied to all clusters born-in-fleet.
Instance Attribute Summary collapse
-
#binary_authorization_config ⇒ ::Google::Cloud::GkeHub::V1::BinaryAuthorizationConfig
Optional.
-
#compliance_posture_config ⇒ ::Google::Cloud::GkeHub::V1::CompliancePostureConfig
Optional.
-
#security_posture_config ⇒ ::Google::Cloud::GkeHub::V1::SecurityPostureConfig
Enable/Disable Security Posture features for the cluster.
Instance Attribute Details
#binary_authorization_config ⇒ ::Google::Cloud::GkeHub::V1::BinaryAuthorizationConfig
Returns Optional. Enable/Disable binary authorization features for the cluster.
90 91 92 93 |
# File 'proto_docs/google/cloud/gkehub/v1/fleet.rb', line 90 class DefaultClusterConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#compliance_posture_config ⇒ ::Google::Cloud::GkeHub::V1::CompliancePostureConfig
Returns Optional. Enable/Disable Compliance Posture features for the cluster. Note that on UpdateFleet, only full replacement of this field is allowed. Users are not allowed for partial updates through field mask.
90 91 92 93 |
# File 'proto_docs/google/cloud/gkehub/v1/fleet.rb', line 90 class DefaultClusterConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#security_posture_config ⇒ ::Google::Cloud::GkeHub::V1::SecurityPostureConfig
Returns Enable/Disable Security Posture features for the cluster.
90 91 92 93 |
# File 'proto_docs/google/cloud/gkehub/v1/fleet.rb', line 90 class DefaultClusterConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |