Class: Google::Cloud::GkeHub::V1::ListBoundMembershipsResponse
- Inherits:
-
Object
- Object
- Google::Cloud::GkeHub::V1::ListBoundMembershipsResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/gkehub/v1/service.rb
Overview
List of Memberships bound to a Scope.
Instance Attribute Summary collapse
-
#memberships ⇒ ::Array<::Google::Cloud::GkeHub::V1::Membership>
The list of Memberships bound to the given Scope.
-
#next_page_token ⇒ ::String
A token to request the next page of resources from the
ListBoundMembershipsmethod. -
#unreachable ⇒ ::Array<::String>
List of locations that could not be reached while fetching this list.
Instance Attribute Details
#memberships ⇒ ::Array<::Google::Cloud::GkeHub::V1::Membership>
Returns The list of Memberships bound to the given Scope.
656 657 658 659 |
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 656 class ListBoundMembershipsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#next_page_token ⇒ ::String
Returns A token to request the next page of resources from the
ListBoundMemberships method. The value of an empty string means that
there are no more resources to return.
656 657 658 659 |
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 656 class ListBoundMembershipsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#unreachable ⇒ ::Array<::String>
Returns List of locations that could not be reached while fetching this list.
656 657 658 659 |
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 656 class ListBoundMembershipsResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |