Class: Google::Cloud::GkeHub::V1::ListFeaturesRequest
- Inherits:
-
Object
- Object
- Google::Cloud::GkeHub::V1::ListFeaturesRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/gkehub/v1/service.rb
Overview
Request message for GkeHub.ListFeatures method.
Instance Attribute Summary collapse
-
#filter ⇒ ::String
Lists Features that match the filter expression, following the syntax outlined in https://google.aip.dev/160.
-
#order_by ⇒ ::String
One or more fields to compare and use to sort the output.
-
#page_size ⇒ ::Integer
When requesting a 'page' of resources,
page_sizespecifies number of resources to return. -
#page_token ⇒ ::String
Token returned by previous call to
ListFeatureswhich specifies the position in the list from where to continue listing the resources. -
#parent ⇒ ::String
Required.
-
#return_partial_success ⇒ ::Boolean
Optional.
Instance Attribute Details
#filter ⇒ ::String
Returns Lists Features that match the filter expression, following the syntax outlined in https://google.aip.dev/160.
Examples:
Feature with the name "servicemesh" in project "foo-proj":
name = "projects/foo-proj/locations/global/features/servicemesh"
Features that have a label called
foo:labels.foo:*
Features that have a label called
foowhose value isbar:labels.foo = bar.
890 891 892 893 |
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 890 class ListFeaturesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#order_by ⇒ ::String
Returns One or more fields to compare and use to sort the output. See https://google.aip.dev/132#ordering.
890 891 892 893 |
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 890 class ListFeaturesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns When requesting a 'page' of resources, page_size specifies number of
resources to return. If unspecified or set to 0, all resources will
be returned.
890 891 892 893 |
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 890 class ListFeaturesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Token returned by previous call to ListFeatures which
specifies the position in the list from where to continue listing the
resources.
890 891 892 893 |
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 890 class ListFeaturesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent (project and location) where the Features will be
listed. Specified in the format projects/*/locations/*.
890 891 892 893 |
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 890 class ListFeaturesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#return_partial_success ⇒ ::Boolean
Returns Optional. If set to true, the response will return partial results when some regions are unreachable and the unreachable field in Feature proto will be populated. If set to false, the request will fail when some regions are unreachable.
890 891 892 893 |
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 890 class ListFeaturesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |