Class: Google::Cloud::GkeHub::V1::ListPermittedScopesResponse
- Inherits:
-
Object
- Object
- Google::Cloud::GkeHub::V1::ListPermittedScopesResponse
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/gkehub/v1/service.rb
Overview
List of permitted Scopes.
Instance Attribute Summary collapse
-
#next_page_token ⇒ ::String
A token to request the next page of resources from the
ListPermittedScopesmethod. -
#scopes ⇒ ::Array<::Google::Cloud::GkeHub::V1::Scope>
The list of permitted Scopes.
Instance Attribute Details
#next_page_token ⇒ ::String
Returns A token to request the next page of resources from the
ListPermittedScopes method. The value of an empty string means
that there are no more resources to return.
320 321 322 323 |
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 320 class ListPermittedScopesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#scopes ⇒ ::Array<::Google::Cloud::GkeHub::V1::Scope>
Returns The list of permitted Scopes.
320 321 322 323 |
# File 'proto_docs/google/cloud/gkehub/v1/service.rb', line 320 class ListPermittedScopesResponse include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |