Class: Google::Cloud::GkeHub::V1::MembershipBinding
- Inherits:
-
Object
- Object
- Google::Cloud::GkeHub::V1::MembershipBinding
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/gkehub/v1/fleet.rb
Overview
MembershipBinding is a subresource of a Membership, representing what Fleet Scopes (or other, future Fleet resources) a Membership is bound to.
Defined Under Namespace
Classes: LabelsEntry
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#delete_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#name ⇒ ::String
The resource name for the membershipbinding itself
projects/{project}/locations/{location}/memberships/{membership}/bindings/{membershipbinding}. -
#scope ⇒ ::String
A Scope resource name in the format
projects/*/locations/*/scopes/*. -
#state ⇒ ::Google::Cloud::GkeHub::V1::MembershipBindingLifecycleState
readonly
Output only.
-
#uid ⇒ ::String
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. When the membership binding was created.
548 549 550 551 552 553 554 555 556 557 558 559 560 |
# File 'proto_docs/google/cloud/gkehub/v1/fleet.rb', line 548 class MembershipBinding include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#delete_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. When the membership binding was deleted.
548 549 550 551 552 553 554 555 556 557 558 559 560 |
# File 'proto_docs/google/cloud/gkehub/v1/fleet.rb', line 548 class MembershipBinding include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Labels for this MembershipBinding.
548 549 550 551 552 553 554 555 556 557 558 559 560 |
# File 'proto_docs/google/cloud/gkehub/v1/fleet.rb', line 548 class MembershipBinding include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns The resource name for the membershipbinding itself
projects/{project}/locations/{location}/memberships/{membership}/bindings/{membershipbinding}.
548 549 550 551 552 553 554 555 556 557 558 559 560 |
# File 'proto_docs/google/cloud/gkehub/v1/fleet.rb', line 548 class MembershipBinding include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#scope ⇒ ::String
Returns A Scope resource name in the format
projects/*/locations/*/scopes/*.
548 549 550 551 552 553 554 555 556 557 558 559 560 |
# File 'proto_docs/google/cloud/gkehub/v1/fleet.rb', line 548 class MembershipBinding include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#state ⇒ ::Google::Cloud::GkeHub::V1::MembershipBindingLifecycleState (readonly)
Returns Output only. State of the membership binding resource.
548 549 550 551 552 553 554 555 556 557 558 559 560 |
# File 'proto_docs/google/cloud/gkehub/v1/fleet.rb', line 548 class MembershipBinding include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#uid ⇒ ::String (readonly)
Returns Output only. Google-generated UUID for this resource. This is unique across all membershipbinding resources. If a membershipbinding resource is deleted and another resource with the same name is created, it gets a different uid.
548 549 550 551 552 553 554 555 556 557 558 559 560 |
# File 'proto_docs/google/cloud/gkehub/v1/fleet.rb', line 548 class MembershipBinding include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. When the membership binding was last updated.
548 549 550 551 552 553 554 555 556 557 558 559 560 |
# File 'proto_docs/google/cloud/gkehub/v1/fleet.rb', line 548 class MembershipBinding include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |