Class: Google::Cloud::GkeHub::V1::RBACRoleBinding
- Inherits:
-
Object
- Object
- Google::Cloud::GkeHub::V1::RBACRoleBinding
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/gkehub/v1/fleet.rb
Overview
RBACRoleBinding represents a rbacrolebinding across the Fleet
Defined Under Namespace
Classes: LabelsEntry, Role
Instance Attribute Summary collapse
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#delete_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#group ⇒ ::String
Group is the group, as seen by the kubernetes cluster.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Optional.
-
#name ⇒ ::String
The resource name for the rbacrolebinding
projects/{project}/locations/{location}/scopes/{scope}/rbacrolebindings/{rbacrolebinding}orprojects/{project}/locations/{location}/memberships/{membership}/rbacrolebindings/{rbacrolebinding}. -
#role ⇒ ::Google::Cloud::GkeHub::V1::RBACRoleBinding::Role
Required.
-
#state ⇒ ::Google::Cloud::GkeHub::V1::RBACRoleBindingLifecycleState
readonly
Output only.
-
#uid ⇒ ::String
readonly
Output only.
-
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#user ⇒ ::String
User is the name of the user as seen by the kubernetes cluster, example "alice" or "alice@domain.tld".
Instance Attribute Details
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. When the rbacrolebinding was created.
360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/gkehub/v1/fleet.rb', line 360 class RBACRoleBinding include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Role is the type for Kubernetes roles # @!attribute [rw] predefined_role # @return [::Google::Cloud::GkeHub::V1::RBACRoleBinding::Role::PredefinedRoles] # predefined_role is the Kubernetes default role to use # @!attribute [rw] custom_role # @return [::String] # Optional. custom_role is the name of a custom KubernetesClusterRole to # use. class Role include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # PredefinedRoles is an ENUM representation of the default Kubernetes Roles module PredefinedRoles # UNKNOWN UNKNOWN = 0 # ADMIN has EDIT and RBAC permissions ADMIN = 1 # EDIT can edit all resources except RBAC EDIT = 2 # VIEW can only read resources VIEW = 3 # ANTHOS_SUPPORT gives Google Support read-only access to a number of # cluster resources. ANTHOS_SUPPORT = 4 end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#delete_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. When the rbacrolebinding was deleted.
360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/gkehub/v1/fleet.rb', line 360 class RBACRoleBinding include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Role is the type for Kubernetes roles # @!attribute [rw] predefined_role # @return [::Google::Cloud::GkeHub::V1::RBACRoleBinding::Role::PredefinedRoles] # predefined_role is the Kubernetes default role to use # @!attribute [rw] custom_role # @return [::String] # Optional. custom_role is the name of a custom KubernetesClusterRole to # use. class Role include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # PredefinedRoles is an ENUM representation of the default Kubernetes Roles module PredefinedRoles # UNKNOWN UNKNOWN = 0 # ADMIN has EDIT and RBAC permissions ADMIN = 1 # EDIT can edit all resources except RBAC EDIT = 2 # VIEW can only read resources VIEW = 3 # ANTHOS_SUPPORT gives Google Support read-only access to a number of # cluster resources. ANTHOS_SUPPORT = 4 end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#group ⇒ ::String
Returns group is the group, as seen by the kubernetes cluster.
Note: The following fields are mutually exclusive: group, user. If a field in that set is populated, all other fields in the set will automatically be cleared.
360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/gkehub/v1/fleet.rb', line 360 class RBACRoleBinding include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Role is the type for Kubernetes roles # @!attribute [rw] predefined_role # @return [::Google::Cloud::GkeHub::V1::RBACRoleBinding::Role::PredefinedRoles] # predefined_role is the Kubernetes default role to use # @!attribute [rw] custom_role # @return [::String] # Optional. custom_role is the name of a custom KubernetesClusterRole to # use. class Role include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # PredefinedRoles is an ENUM representation of the default Kubernetes Roles module PredefinedRoles # UNKNOWN UNKNOWN = 0 # ADMIN has EDIT and RBAC permissions ADMIN = 1 # EDIT can edit all resources except RBAC EDIT = 2 # VIEW can only read resources VIEW = 3 # ANTHOS_SUPPORT gives Google Support read-only access to a number of # cluster resources. ANTHOS_SUPPORT = 4 end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Optional. Labels for this RBACRolebinding.
360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/gkehub/v1/fleet.rb', line 360 class RBACRoleBinding include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Role is the type for Kubernetes roles # @!attribute [rw] predefined_role # @return [::Google::Cloud::GkeHub::V1::RBACRoleBinding::Role::PredefinedRoles] # predefined_role is the Kubernetes default role to use # @!attribute [rw] custom_role # @return [::String] # Optional. custom_role is the name of a custom KubernetesClusterRole to # use. class Role include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # PredefinedRoles is an ENUM representation of the default Kubernetes Roles module PredefinedRoles # UNKNOWN UNKNOWN = 0 # ADMIN has EDIT and RBAC permissions ADMIN = 1 # EDIT can edit all resources except RBAC EDIT = 2 # VIEW can only read resources VIEW = 3 # ANTHOS_SUPPORT gives Google Support read-only access to a number of # cluster resources. ANTHOS_SUPPORT = 4 end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#name ⇒ ::String
Returns The resource name for the rbacrolebinding
projects/{project}/locations/{location}/scopes/{scope}/rbacrolebindings/{rbacrolebinding}
or
projects/{project}/locations/{location}/memberships/{membership}/rbacrolebindings/{rbacrolebinding}.
360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/gkehub/v1/fleet.rb', line 360 class RBACRoleBinding include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Role is the type for Kubernetes roles # @!attribute [rw] predefined_role # @return [::Google::Cloud::GkeHub::V1::RBACRoleBinding::Role::PredefinedRoles] # predefined_role is the Kubernetes default role to use # @!attribute [rw] custom_role # @return [::String] # Optional. custom_role is the name of a custom KubernetesClusterRole to # use. class Role include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # PredefinedRoles is an ENUM representation of the default Kubernetes Roles module PredefinedRoles # UNKNOWN UNKNOWN = 0 # ADMIN has EDIT and RBAC permissions ADMIN = 1 # EDIT can edit all resources except RBAC EDIT = 2 # VIEW can only read resources VIEW = 3 # ANTHOS_SUPPORT gives Google Support read-only access to a number of # cluster resources. ANTHOS_SUPPORT = 4 end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#role ⇒ ::Google::Cloud::GkeHub::V1::RBACRoleBinding::Role
Returns Required. Role to bind to the principal.
360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/gkehub/v1/fleet.rb', line 360 class RBACRoleBinding include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Role is the type for Kubernetes roles # @!attribute [rw] predefined_role # @return [::Google::Cloud::GkeHub::V1::RBACRoleBinding::Role::PredefinedRoles] # predefined_role is the Kubernetes default role to use # @!attribute [rw] custom_role # @return [::String] # Optional. custom_role is the name of a custom KubernetesClusterRole to # use. class Role include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # PredefinedRoles is an ENUM representation of the default Kubernetes Roles module PredefinedRoles # UNKNOWN UNKNOWN = 0 # ADMIN has EDIT and RBAC permissions ADMIN = 1 # EDIT can edit all resources except RBAC EDIT = 2 # VIEW can only read resources VIEW = 3 # ANTHOS_SUPPORT gives Google Support read-only access to a number of # cluster resources. ANTHOS_SUPPORT = 4 end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#state ⇒ ::Google::Cloud::GkeHub::V1::RBACRoleBindingLifecycleState (readonly)
Returns Output only. State of the rbacrolebinding resource.
360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/gkehub/v1/fleet.rb', line 360 class RBACRoleBinding include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Role is the type for Kubernetes roles # @!attribute [rw] predefined_role # @return [::Google::Cloud::GkeHub::V1::RBACRoleBinding::Role::PredefinedRoles] # predefined_role is the Kubernetes default role to use # @!attribute [rw] custom_role # @return [::String] # Optional. custom_role is the name of a custom KubernetesClusterRole to # use. class Role include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # PredefinedRoles is an ENUM representation of the default Kubernetes Roles module PredefinedRoles # UNKNOWN UNKNOWN = 0 # ADMIN has EDIT and RBAC permissions ADMIN = 1 # EDIT can edit all resources except RBAC EDIT = 2 # VIEW can only read resources VIEW = 3 # ANTHOS_SUPPORT gives Google Support read-only access to a number of # cluster resources. ANTHOS_SUPPORT = 4 end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#uid ⇒ ::String (readonly)
Returns Output only. Google-generated UUID for this resource. This is unique across all rbacrolebinding resources. If a rbacrolebinding resource is deleted and another resource with the same name is created, it gets a different uid.
360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/gkehub/v1/fleet.rb', line 360 class RBACRoleBinding include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Role is the type for Kubernetes roles # @!attribute [rw] predefined_role # @return [::Google::Cloud::GkeHub::V1::RBACRoleBinding::Role::PredefinedRoles] # predefined_role is the Kubernetes default role to use # @!attribute [rw] custom_role # @return [::String] # Optional. custom_role is the name of a custom KubernetesClusterRole to # use. class Role include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # PredefinedRoles is an ENUM representation of the default Kubernetes Roles module PredefinedRoles # UNKNOWN UNKNOWN = 0 # ADMIN has EDIT and RBAC permissions ADMIN = 1 # EDIT can edit all resources except RBAC EDIT = 2 # VIEW can only read resources VIEW = 3 # ANTHOS_SUPPORT gives Google Support read-only access to a number of # cluster resources. ANTHOS_SUPPORT = 4 end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. When the rbacrolebinding was last updated.
360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/gkehub/v1/fleet.rb', line 360 class RBACRoleBinding include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Role is the type for Kubernetes roles # @!attribute [rw] predefined_role # @return [::Google::Cloud::GkeHub::V1::RBACRoleBinding::Role::PredefinedRoles] # predefined_role is the Kubernetes default role to use # @!attribute [rw] custom_role # @return [::String] # Optional. custom_role is the name of a custom KubernetesClusterRole to # use. class Role include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # PredefinedRoles is an ENUM representation of the default Kubernetes Roles module PredefinedRoles # UNKNOWN UNKNOWN = 0 # ADMIN has EDIT and RBAC permissions ADMIN = 1 # EDIT can edit all resources except RBAC EDIT = 2 # VIEW can only read resources VIEW = 3 # ANTHOS_SUPPORT gives Google Support read-only access to a number of # cluster resources. ANTHOS_SUPPORT = 4 end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#user ⇒ ::String
Returns user is the name of the user as seen by the kubernetes cluster, example "alice" or "alice@domain.tld"
Note: The following fields are mutually exclusive: user, group. If a field in that set is populated, all other fields in the set will automatically be cleared.
360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'proto_docs/google/cloud/gkehub/v1/fleet.rb', line 360 class RBACRoleBinding include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Role is the type for Kubernetes roles # @!attribute [rw] predefined_role # @return [::Google::Cloud::GkeHub::V1::RBACRoleBinding::Role::PredefinedRoles] # predefined_role is the Kubernetes default role to use # @!attribute [rw] custom_role # @return [::String] # Optional. custom_role is the name of a custom KubernetesClusterRole to # use. class Role include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # PredefinedRoles is an ENUM representation of the default Kubernetes Roles module PredefinedRoles # UNKNOWN UNKNOWN = 0 # ADMIN has EDIT and RBAC permissions ADMIN = 1 # EDIT can edit all resources except RBAC EDIT = 2 # VIEW can only read resources VIEW = 3 # ANTHOS_SUPPORT gives Google Support read-only access to a number of # cluster resources. ANTHOS_SUPPORT = 4 end end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |